package com.tmh.fileprovider_plugin;

import android.annotation.TargetApi;
import android.net.Uri;
import android.os.Build;
import android.util.Log;

import androidx.annotation.NonNull;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** FileproviderPlugin */
public class FileproviderPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "fileprovider_plugin");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getFileContents")) {
      try {
        ArrayList arguments = (ArrayList) call.arguments;
        String filename = (String) arguments.get(0);
        String content = read_file(filename);
        result.success(content);
      } catch (Exception ex) {
        result.error("1", ex.getMessage(), ex.getStackTrace());
      }
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @TargetApi(Build.VERSION_CODES.O)
  public String read_file(String filename) {
    Path path = Paths.get(filename);
    Path normalizedPath = path.normalize();
    Log.d("normalized", normalizedPath.toString());

    final File file = new File(normalizedPath.toString());

    try {
      FileInputStream fis = new FileInputStream(file);
      StringBuilder fileContent = new StringBuilder("");

      byte[] buffer = new byte[1024];

      int n;
      while ((n = fis.read(buffer)) != -1) {
        fileContent.append(new String(buffer, 0, n));
      }
      return fileContent.toString();
    } catch (FileNotFoundException e) {
      Log.d("error",e.toString());
      return null;
    } catch (IOException e) {
      Log.d("error",e.toString());
      return null;
    }
  }
}